GrowthEstimates: GrowthEstimates

Description Usage Arguments Value

View source: R/Other_Functions.R

Description

Given a dataset and two years, creates a new dataset containing population estimates for years between those two days

Usage

1
GrowthEstimates(data, cols, start = 2000, end = 2010)

Arguments

data

a dataset with YEAR, ID columbs, as well as specified population columns

cols

a string or list of strings naming columns to make estimates on

start

a year for which you have data from which to start making estimates

end

a year for which you have data until which you make estimates

Value

A dataset containing population estimates–expotential growth–between the given years for the given population columns


cmpear/UnempDeaths documentation built on May 22, 2020, 6:50 a.m.