Description Usage Arguments Value
View source: R/Other_Functions.R
Given a dataset and two years, creates a new dataset containing population estimates for years between those two days
1 | GrowthEstimates(data, cols, start = 2000, end = 2010)
|
data |
a dataset with YEAR, ID columbs, as well as specified population columns |
cols |
a string or list of strings naming columns to make estimates on |
start |
a year for which you have data from which to start making estimates |
end |
a year for which you have data until which you make estimates |
A dataset containing population estimates–expotential growth–between the given years for the given population columns
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.